@@ -1,4 +1,4 @@
-/*      $Id: keys_management.c 21572 2006-05-07 14:29:21Z olivier $
+/*      $Id: keys_management.c 23834 2006-11-12 09:09:28Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -65,7 +65,7 @@ parseKeyString (char *str)
         /* There is a modifier */
         gchar *tmp;
 
-        tmp = g_ascii_strdown ((gchar *) str, -1);
+        tmp = g_ascii_strdown ((gchar *) str, strlen (str));
 
         my_key->keycode = XKeysymToKeycode (GDK_DISPLAY_XDISPLAY (gdisplay), XStringToKeysym (++k));
         if (strstr (tmp, "shift"))
