@@ -1,4 +1,4 @@
-/*      $Id: shortcuts_plugin.c 22694 2006-08-09 12:01:02Z pollux $
+/*      $Id: shortcuts_plugin.c 23710 2006-11-05 09:25:45Z olivier $
  *
  * Copyright (c) 2006 Jean-Francois Wauthy <pollux@xfce.org>
  *                    Olivier Fourdan <fourdan@xfce.org>
@@ -986,7 +986,6 @@ cb_compose_shortcut (GtkWidget * widget, GdkEventKey * event, gpointer data)
     modifiers = event->state & (~consumed_modifiers | GDK_MODIFIER_MASK);
     modifiers = modifiers & gtk_accelerator_get_default_mod_mask ();
     accelerator = gtk_accelerator_name (keyval, modifiers);
-
     shortcuts = g_strsplit_set (accelerator, "<>", 0);
 
     current_shortcut = shortcuts;
@@ -1178,7 +1177,11 @@ cb_treeview_shortcuts_activate (GtkWidget * treeview, GtkTreePath * path, GtkTre
         /* Create dialog */
         dialog_compose = gtk_dialog_new_with_buttons (_("Set shortcut"), 
             GTK_WINDOW (gtk_widget_get_toplevel(dialog->dialog_keyboard)),
-            GTK_DIALOG_MODAL, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+            GTK_DIALOG_MODAL, NULL);
+
+	button = xfce_create_mixed_button (GTK_STOCK_CANCEL, _("Cancel"));
+        gtk_widget_show (button);
+        gtk_dialog_add_action_widget (GTK_DIALOG (dialog_compose), button, GTK_RESPONSE_CANCEL);
 
         button = xfce_create_mixed_button (GTK_STOCK_CLEAR, _("No shortcut"));
         gtk_widget_show (button);
@@ -1845,14 +1848,13 @@ GtkWidget* shortcuts_plugin_create_dialog (KeyboardMcsDialog *dialog)
     gtk_widget_show (hbox);
 
     /* */
-    frame = xfce_framebox_new (_("Themes"), FALSE);
-    gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (hbox), frame, FALSE, TRUE, 0);
-
     vbox = gtk_vbox_new (FALSE, BORDER);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
     gtk_widget_show (vbox);
-    xfce_framebox_add (XFCE_FRAMEBOX (frame), vbox);
+
+    frame = xfce_create_framebox_with_content (_("Themes"), vbox);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (hbox), frame, FALSE, TRUE, 0);
 
     dialog->scrolledwindow_themes = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (dialog->scrolledwindow_themes), 
@@ -1876,14 +1878,13 @@ GtkWidget* shortcuts_plugin_create_dialog (KeyboardMcsDialog *dialog)
     gtk_widget_set_sensitive (dialog->button_del_theme, FALSE);
 
     /* */
-    frame = xfce_framebox_new (_("Shortcuts"), FALSE);
-    gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
-
     vbox = gtk_vbox_new (FALSE, BORDER);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER);
     gtk_widget_show (vbox);
-    xfce_framebox_add (XFCE_FRAMEBOX (frame), vbox);
+
+    frame = xfce_create_framebox_with_content (_("Shortcuts"), vbox);
+    gtk_widget_show (frame);
+    gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
 
     dialog->scrolledwindow_shortcuts = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (dialog->scrolledwindow_shortcuts), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
